class Panic(RuntimeError):
    ...  # pragma: no cover
